wsireg modules
==============

WsiReg2D API
-------------

.. automodule:: wsireg.wsireg2d
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   wsireg.reg_images
   wsireg.reg_transforms
   wsireg.reg_shapes
   wsireg.writers
   wsireg.parameter_maps
   wsireg.utils



